/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.local;

import org.ogf.graap.wsag.api.Agreement;
import org.ogf.graap.wsag.api.client.AgreementClient;
import org.ogf.graap.wsag.api.client.AgreementRegistryService;
import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;

/**
 * Implementation of an agreement registry service for local access. Only for internal use.
 * 
 * @author Oliver Waeldrich
 * 
 */
public class LocalAgreementFactoryRegistryImpl extends LocalWsClient implements AgreementRegistryService
{

    private AgreementClient[] agreements;

    /**
     * default constructor
     */
    public LocalAgreementFactoryRegistryImpl()
    {
        this( new Agreement[0] );
    }

    /**
     * 
     * @param source
     *            the agreements associated with this registry.
     */
    public LocalAgreementFactoryRegistryImpl( Agreement[] source )
    {
        agreements = new AgreementClient[source.length];
        for ( int i = 0; i < source.length; i++ )
        {
            agreements[i] = new LocalAgreementClientImpl( source[i] );
        }
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.ogf.graap.wsag.api.client.AgreementRegistryService#listAgreements()
     */
    public AgreementClient[] listAgreements() throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreements;
    }

}
