/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.local;

import org.ogf.graap.wsag.api.Agreement;
import org.ogf.graap.wsag.api.client.AgreementService;
import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.schemas.graap.wsAgreement.AgreementContextType;
import org.ogf.schemas.graap.wsAgreement.AgreementStateType;
import org.ogf.schemas.graap.wsAgreement.GuaranteeTermStateType;
import org.ogf.schemas.graap.wsAgreement.ServiceTermStateType;
import org.ogf.schemas.graap.wsAgreement.TermTreeType;
import org.ogf.schemas.graap.wsAgreement.TerminateInputType;

/**
 * Implementation of the WSAG4J client API for accessing local agreement instances.
 * 
 * @author Oliver Waeldrich
 * 
 */
public class LocalAgreementServiceImpl extends LocalWsClient implements AgreementService
{

    private Agreement agreement;

    /**
     * 
     * @param agreement
     *            the local agreement instance
     */
    public LocalAgreementServiceImpl( Agreement agreement )
    {
        this.agreement = agreement;
    }

    /**
     * {@inheritDoc}
     */
    public String getAgreementId() throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getAgreementId();
    }

    /**
     * {@inheritDoc}
     */
    public AgreementContextType getContext() throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getContext();
    }

    /**
     * {@inheritDoc}
     */
    public GuaranteeTermStateType[] getGuaranteeTermStates()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getGuaranteeTermStates();
    }

    /**
     * {@inheritDoc}
     */
    public String getName() throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getName();
    }

    /**
     * {@inheritDoc}
     */
    public ServiceTermStateType[] getServiceTermStates()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getServiceTermStates();
    }

    /**
     * {@inheritDoc}
     */
    public AgreementStateType getState() throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getState();
    }

    /**
     * {@inheritDoc}
     */
    public TermTreeType getTerms() throws ResourceUnknownException, ResourceUnavailableException
    {
        return agreement.getTerms();
    }

    /**
     * {@inheritDoc}
     */
    public void terminate( TerminateInputType reason )
        throws ResourceUnknownException, ResourceUnavailableException
    {
        agreement.terminate( reason );
    }

    /**
     * {@inheritDoc}
     * 
     * local implementation does nothing here
     */
    public void destroy() throws ResourceUnknownException, ResourceUnavailableException
    {
        // do nothing
    }

}
