/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.local;

import org.apache.xmlbeans.XmlObject;
import org.ogf.graap.wsag.api.Negotiation;
import org.ogf.graap.wsag.api.client.NegotiationService;
import org.ogf.graap.wsag.api.exceptions.NegotiationException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.schemas.graap.wsAgreement.AgreementTemplateType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationContextType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationOfferType;

/**
 * Default implementation of a negotiation service client for local access to a negotiation service instance.
 * Internal use only.
 * 
 * @author hrasheed
 * 
 */
public class LocalNegotiationServiceImpl extends LocalWsClient implements NegotiationService
{

    private Negotiation negotiation;;

    /**
     * 
     * @param negotiation
     *            the negotiation service
     */
    public LocalNegotiationServiceImpl( Negotiation negotiation )
    {
        this.negotiation = negotiation;
    }

    /**
     * {@inheritDoc}
     */
    public NegotiationContextType getNegotiationContext()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.getNegotiationContext();
    }

    /**
     * {@inheritDoc}
     */
    public AgreementTemplateType[] getNegotiableTemplates()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.getNegotiableTemplates();
    }

    /**
     * {@inheritDoc}
     */
    public NegotiationOfferType[] getNegotiationOffers()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.getNegotiationOffers();
    }

    /**
     * {@inheritDoc}
     */
    public NegotiationOfferType[] negotiate( NegotiationOfferType[] quotes )
        throws NegotiationException, ResourceUnknownException, ResourceUnavailableException
    {
        XmlObject[] nocriticalExtensions = new XmlObject[0];
        return negotiation.negotiate( quotes, nocriticalExtensions );
    }

    /**
     * {@inheritDoc}
     */
    public void advertise( NegotiationOfferType[] quotes )
        throws NegotiationException, ResourceUnknownException, ResourceUnavailableException
    {
        XmlObject[] nocriticalExtensions = new XmlObject[0];
        negotiation.advertise( quotes, nocriticalExtensions );
    }

    /**
     * {@inheritDoc}
     */
    public void terminate() throws ResourceUnavailableException, ResourceUnknownException
    {
        negotiation.terminate();
    }

    /**
     * {@inheritDoc}
     */
    public void destroy() throws ResourceUnavailableException, ResourceUnknownException
    {
        // do nothing
    }

}
