/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.local;

import java.util.Properties;

import org.ogf.graap.wsag.api.WsagConstants;
import org.ogf.graap.wsag.api.client.WsClient;
import org.ogf.graap.wsag.api.security.ISecurityProperties;
import org.ogf.graap.wsag.api.security.SecurityProperties;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * Default implementation of a WS client for local access. Internal use only.
 * 
 * @author Oliver Waeldrich
 * 
 */
public class LocalWsClient implements WsClient
{

    private EndpointReferenceType epr;

    private Properties properties;

    private ISecurityProperties securityProperties;

    private boolean trace = false;

    /**
     * Default constructor
     */
    public LocalWsClient()
    {
        //
        // initialize agreement epr
        //
        epr = EndpointReferenceType.Factory.newInstance();
        epr.addNewAddress().setStringValue( "http://127.0.0.1:8080/wsag4j"
                                                + WsagConstants.AGREEMENT_SERVICE_URI );

        //
        // initialize properties
        //
        properties = new Properties();

        //
        // initialize security properties
        //
        securityProperties = new SecurityProperties( null );
    }

    /**
     * returns a dummy EPR for this agreement.
     * 
     * {@inheritDoc}
     */
    public EndpointReferenceType getEndpoint()
    {
        return epr;
    }

    /**
     * {@inheritDoc}
     */
    public Properties getProperties()
    {
        return properties;
    }

    /**
     * {@inheritDoc}
     */
    public ISecurityProperties getSecurityProperties()
    {
        return securityProperties;
    }

    /**
     * {@inheritDoc}
     */
    public boolean isUsingTrace()
    {
        return trace;
    }

    /**
     * {@inheritDoc}
     */
    public void setProperties( Properties properties )
    {
        this.properties = properties;
    }

    /**
     * {@inheritDoc}
     */
    public void setTrace( boolean trace )
    {
        this.trace = trace;
    }

    /**
     * @return this WS client instance
     */
    public WsClient getWebServiceClient()
    {
        return this;
    }

}
